about summary refs log tree commit diff
path: root/src/test/compile-fail
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2018-05-27 22:28:11 +0000
committerbors <bors@rust-lang.org>2018-05-27 22:28:11 +0000
commit5f308ee4194f22cebc4a481494f4fcf07b143934 (patch)
treeb45d95ee31cb052071f3066948091e98753d905f /src/test/compile-fail
parentad2591cffc8b7e56f7302c8baee04391f05e0c60 (diff)
parent0e53b788309c446788335b4fbb478490eea1e667 (diff)
Auto merge of #48309 - mark-i-m:anon_param_lint, r=nikomatsakis
Make anon params lint warn-by-default

This is intended as a followup on anonymous parameters deprecation.

Cross-posting from #41686:

> After having read a bit more of the discussion that I can find, I propose a more aggressive deprecation strategy:
> - We make the lint warn-by-default as soon as possible
> - We make anon parameters a hard error at the epoch boundary

cc @matklad @est31 @aturon
Diffstat (limited to 'src/test/compile-fail')
-rw-r--r--src/test/compile-fail/anon-params-deprecated.rs6
-rw-r--r--src/test/compile-fail/future-incompatible-lint-group.rs2
2 files changed, 4 insertions, 4 deletions
diff --git a/src/test/compile-fail/future-incompatible-lint-group.rs b/src/test/compile-fail/future-incompatible-lint-group.rs
index e6a39f95e66..5f320135edf 100644
--- a/src/test/compile-fail/future-incompatible-lint-group.rs
+++ b/src/test/compile-fail/future-incompatible-lint-group.rs
@@ -11,7 +11,7 @@
 #![deny(future_incompatible)]
 
 trait Tr {
-    fn f(u8) {} //~ ERROR use of deprecated anonymous parameter
+    fn f(u8) {} //~ ERROR anonymous parameters are deprecated
                 //~^ WARN this was previously accepted
 }
diff --git a/src/test/compile-fail/anon-params-deprecated.rs b/src/test/compile-fail/anon-params-deprecated.rs
index 76edae17dc1..4d37ba920f3 100644
--- a/src/test/compile-fail/anon-params-deprecated.rs
+++ b/src/test/compile-fail/anon-params-deprecated.rs
@@ -12,13 +12,13 @@
 // Test for the anonymous_parameters deprecation lint (RFC 1685)
 
 trait T {
-    fn foo(i32); //~ ERROR use of deprecated anonymous parameter
+    fn foo(i32); //~ ERROR anonymous parameters are deprecated
                  //~| WARNING hard error
 
     fn bar_with_default_impl(String, String) {}
     //~^ ERROR use of deprecated anonymous parameter
     //~| WARNING hard error
     //~| ERROR use of deprecated anonymous parameter
     //~| WARNING hard error
 }
 
@@ -12,13 +12,13 @@
 
     fn bar_with_default_impl(String, String) {}
-    //~^ ERROR use of deprecated anonymous parameter
+    //~^ ERROR anonymous parameters are deprecated
     //~| WARNING hard error
@@ -12,13 +12,13 @@
     //~| WARNING hard error
-    //~| ERROR use of deprecated anonymous parameter
+    //~| ERROR anonymous parameters are deprecated
     //~| WARNING hard error
 }